==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebTabHeaderElementDescriptionMetadata } from "./WebTabHeaderElementDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDetailDescription } from "./WebTabHeaderConnectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebTabHeaderConnectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderConnectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a == null) {
                WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
            WebTabHeaderElementDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Pane", "ExportedType:WebContentPane");
            a.item("Element", "ExportedType:WebTabHeaderElement");
        }
        static d(a) {
            WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebTabHeaderConnectionEventArgsDetail", () => new WebTabHeaderConnectionEventArgsDetailDescription());
            a.ac("WebTabHeaderConnectionEventArgsDetail", WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDetailDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebTabHeaderElementDescriptionMetadata } from "./WebTabHeaderElementDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDetailDescription } from "./WebTabHeaderConnectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebTabHeaderConnectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderConnectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a == null) {
                WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
            WebTabHeaderElementDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Pane", "ExportedType:WebContentPane");
            a.item("Element", "ExportedType:WebTabHeaderElement");
        }
        static d(a) {
            WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebTabHeaderConnectionEventArgsDetail", () => new WebTabHeaderConnectionEventArgsDetailDescription());
            a.ad("WebTabHeaderConnectionEventArgsDetail", WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderConnectionEventArgsDetailDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDetailDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDetailDescriptionMetadata;
})();
